@@ -27,7 +27,7 @@ int main()
 
 	struct fann *ann = fann_create_from_file("xor_float.net");
 	
-	input[0] = 0;
+	input[0] = -1;
 	input[1] = 1;
 	calc_out = fann_run(ann, input);
 
